# -*- coding: latin1 -*-
#
# Copyright (C) 2003 Ayose Cazorla Len
#
# Authors
#       Ayose Cazorla <ayose.cazorla@hispalinux.es>
#
# This file is part of Pyslide.
#
# Pyslide is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Pyslide is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Pyslide; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import pygame

class Page:
    def __init__ (self):
        self.stage = 0
        self.groups = []
        self.bg = None
        self.ttl = None

    def current_groups(self):
        return self.groups[:self.stage+1]

    def new_group(self):
        self.groups.append([])
        return len(self.groups) - 1

    def add_item (self, item, group=-1):
        if not self.groups:
            self.new_group()

        self.groups[group].append(item)

    def next_stage (self):
        if self.stage < len(self.groups) - 1:
            self.stage += 1
            return self.groups[self.stage]

        return None

    def prev_stage (self):
        if self.stage > 0:
            self.stage -= 1
            return self.groups[self.stage + 1]

        return None

    def set_stage(self, n):
        if n < 0:
            self.stage = len(self.groups) + n
        else:
            self.stage = n

    def SetBGGrad (self, topcolor, bottomcolor):
        import misc

        self.bg = pygame.Surface(pygame.display.get_surface().get_size())
        grade = misc.RenderGradient(self.bg, topcolor, bottomcolor)
        pygame.surfarray.blit_array(self.bg, grade)    

    def SetBGColor (self, color):
        self.bg = pygame.Surface(pygame.display.get_surface().get_size())
        self.bg.fill(color)

    def SetBG (self, imagename, scale=True):
        import misc
        size = pygame.display.get_surface().get_size()
        img = misc.load_image(imagename)
        if scale:
            img = pygame.transform.scale(img, size)

        self.bg = pygame.Surface(size).convert()
        self.bg.fill(0)
        self.bg.blit(img, (0,0))


    def set_ttl(self, ttl):
        self.ttl = ttl
