# -*- coding: latin1 -*-
#
# Copyright (C) 2003 Ayose Cazorla Len
#
# Authors
#       Ayose Cazorla <ayose.cazorla@hispalinux.es>
#
# This file is part of Pyslide.
#
# Pyslide is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Pyslide is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Pyslide; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


class PyslideError(Exception):
    pass

def RenderGradient(surf, topcolor, bottomcolor):
    '''Creates a new 3d vertical gradient array.

    This code was copied from the vgrade example'''

    import pygame
    from Numeric import array, repeat, resize, arange, \
        Float, NewAxis, Int, UnsignedInt8

    topcolor = array(topcolor, copy=0)
    bottomcolor = array(bottomcolor, copy=0)
    diff = bottomcolor - topcolor
    width, height = surf.get_size()
    # create array from 0.0 to 1.0 triplets
    column = arange(height, typecode=Float)/height
    column = repeat(column[:, NewAxis], [3], 1)
    # create a single column of gradient
    column = topcolor + (diff * column).astype(Int)
    # make the column a 3d image column by adding X
    column = column.astype(UnsignedInt8)[NewAxis,:,:]
    #3d array into 2d array
    column = pygame.surfarray.map_array(surf, column)
    # stretch the column into a full image
    return resize(column, (width, height))
 


def parse_color(c):

    from pygame.colordict import THECOLORS

    if THECOLORS.has_key(c.lower()):
        return THECOLORS[c.lower()][:3]

    try:
        r, g, b = map(lambda s: int(s), c.split(',', 2))
    except ValueError:
        import sys
        print >> sys.stderr, 'Invalid color string:', c
        return None

    return r, g, b


def load_image(src, EmptyOnError=True, _cache=[]):

    import os.path
    path = os.path.abspath(src)

    # find if the image is loaded
    for name, image in _cache:
        if name == path:
            return image

    # if not, load it
    try:
        import pygame
        image = pygame.image.load(path)
    except pygame.error:
        if EmptyOnError:
            return pygame.Surface((0,0))
        else:
            return None

    # max 10 images
    if len(_cache) >= 10: del _cache[0]
    _cache.append( (path, image) )

    return image


def map_units(x = None, y = None):

    import pygame
    cx, cy = pygame.display.get_surface().get_size()

    if None not in (x, y):
        x = cx * x / 1000
        y = cy * y / 750
        return x, y
    elif x is not None:
        return cx * x / 1000
    elif y is not None:
        return cy * y / 750

try:
    # Load the optimized functions
    from cmisc import set_alpha, set_valpha, set_halpha

except ImportError:

    # If there is no cmisc module, create the equivalents

    def set_alpha(surface, alpha):
        import Numeric, pygame
        alpha_array = pygame.surfarray.pixels_alpha(surface)
        b = Numeric.array(alpha_array) * alpha
        alpha_array[:,:] = b.astype('b')


    def set_halpha(surface, limit):
        import pygame, Numeric
        width, height = surface.get_size()
        alpha_array = pygame.surfarray.pixels_alpha(surface)
        alpha_array[limit:,:] = 0

        bottom, top = max(0, limit - 100), min(width, limit)
        for x in range(bottom, top):
            b = Numeric.array(alpha_array[x,:]) * ((limit - x) / 100.)
            alpha_array[x,:] = b.astype('b')


    def set_valpha(surface, limit):
        import pygame, Numeric
        width, height = surface.get_size()
        alpha_array = pygame.surfarray.pixels_alpha(surface)
        alpha_array[:,limit:] = 0

        bottom, top = max(0, limit - 100), min(height, limit)
        for y in range(bottom, top):
            b = Numeric.array(alpha_array[:,y]) * ((limit - y) / 100.)
            alpha_array[:,y] = b.astype('b')

